from typing import Optional, Dict, Any

from ppa import ui

from ._api import get_client


def set_kerberos_config(*, address: Optional[str] = None, api_key: Optional[str] = None, config: Dict[str, Any]) -> None:
    if missing := [k for k in ["address", "domain", "username", "password"] if k not in config]:
        message = f"The following keys are missing from the supplied Kerberos configuration: {', '.join(missing)}"
        ui.output_error(message)
        raise KeyError(message)
    try:
        with get_client(address=address, api_key=api_key) as ppa:
            return ppa.set_kerberos_config(**config)
    except Exception as e:
        ui.output_error(str(e))
        raise e
